Enum HostError
Source pub enum HostError<E> {
Busy,
Mac(E),
}
Error returned when a Host cannot make progress.
Busy means some other caller already holds the underlying shared
MacHandle borrow. Mac wraps the underlying runtime failure.
Formats the value using the given formatter.
Read more
Converts to this type from the input type.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.