LocalNode

Struct LocalNode 

pub struct LocalNode<M: MacBackend> { /* private fields */ }
Per-identity application handle.

LocalNode owns its channel membership set via shared interior state. Different LocalNode instances (for different identities) may join different channel sets.

Implementations

Source

impl<M: MacBackend> LocalNode<M>

pub fn identity_id(&self) -> LocalIdentityId

The identity slot this node operates on.

pub fn peer(&self, key: PublicKey) -> Result<PeerConnection<Self>, NodeError<M>>

Create a peer connection (registers peer in MAC if new).

pub fn on_receive<F>(&self, handler: F) -> Subscription
where F: FnMut(&ReceivedPacketRef<'_>) -> bool + 'static,

pub fn on_node_discovered<F>(&self, handler: F) -> Subscription
where F: FnMut(PublicKey, Option<&str>) + 'static,

pub fn on_beacon<F>(&self, handler: F) -> Subscription
where F: FnMut(NodeHint, Option<PublicKey>) + 'static,

pub fn on_mac_command<F>(&self, handler: F) -> Subscription
where F: FnMut(PublicKey, &OwnedMacCommand) + 'static,

pub fn on_ack_received<F>(&self, handler: F) -> Subscription
where F: FnMut(PublicKey, SendToken) + 'static,

pub fn on_ack_timeout<F>(&self, handler: F) -> Subscription
where F: FnMut(PublicKey, SendToken) + 'static,

pub fn on_pfs_established<F>(&self, handler: F) -> Subscription
where F: FnMut(PublicKey) + 'static,

pub fn on_pfs_ended<F>(&self, handler: F) -> Subscription
where F: FnMut(PublicKey) + 'static,

pub async fn request_pfs( &self, peer: &PublicKey, duration_minutes: u16, options: &SendOptions, ) -> Result<SendProgressTicket, NodeError<M>>

pub async fn end_pfs( &self, peer: &PublicKey, options: &SendOptions, ) -> Result<(), NodeError<M>>

pub fn pfs_status(&self, peer: &PublicKey) -> Result<PfsStatus, NodeError<M>>

pub fn join(&self, channel: &Channel) -> Result<BoundChannel<M>, NodeError<M>>

Join a channel. Registers the channel key in the MAC if this is the first node to join it. Returns the bound channel handle.

pub fn leave(&self, channel: &Channel) -> Result<(), NodeError<M>>

Leave a channel. Marks the membership entry inactive and bumps that entry’s generation counter.

pub fn bound_channel(&self, channel: &Channel) -> Option<BoundChannel<M>>

Get a handle to an already-joined channel.

pub fn bound_channels(&self) -> Vec<BoundChannel<M>>

List all joined channels.